==> pwsafe-3.05-src.zip: pwsafe-3.05-src/resource3.h <==
//{{NO_DEPENDENCIES}}

// Strings

//  Usage
#define IDS_USAGE                       5000

// Window state
#define IDS_ALWAYSONTOP                 5010

// Status bar
#define IDS_STATCOMPANY                 5020
#define IDS_STATAUTOTYPE                5021
#define IDS_STATBROWSE                  5022
#define IDS_STATCOPYNOTES               5023
#define IDS_STATCOPYPASSWORD            5024
#define IDS_STATCOPYUSERNAME            5025
#define IDS_STATVIEWEDIT                5026
#define IDS_MODIFIED                    5027
#define IDS_READ_ONLY                   5028
#define IDS_STAT_NUM_IN_DB              5029
#define IDS_CONFIG_BLANK                5030

// Tooltips
#define IDS_RESETPWHISTORYOFF           5100
#define IDS_RESETPWHISTORYON            5101
#define IDS_SETMAXPWHISTORY             5102
#define IDS_REGDEL_CB                   5103
#define IDS_BACKUPBEFORESAVE            5104
#define IDS_USERBACKUPOTHERLOCATION     5106
#define IDS_MAINTAINDATETIMESTAMPS      5107
#define IDS_OTHERBROWSERLOCATION        5108

// Program strings
#define IDS_DCAAUTOTYPE                 5200
#define IDS_DCABROWSE                   5201
#define IDS_DCACOPYNOTES                5202
#define IDS_DCACOPYPASSWORD             5203
#define IDS_DCACOPYUSERNAME             5204
#define IDS_DCAVIEWEDIT                 5205
#define IDS_LITTLEENDIAN                5206
#define IDS_BIGENDIAN                   5207
#define IDS_ENDIANERROR                 5208
#define IDS_FILEERROR1                  5209
#define IDS_FILEERROR2                  5210
#define IDS_ERRORMESSAGE                5211
#define IDS_FILEREADONLY                5212
#define IDS_FILEEXISTS                  5213
#define IDS_INVALIDFLAG                 5214
#define IDS_NOMOREHANDLES               5215
#define IDS_FILEPATHNOTFOUND            5216
#define IDS_TERMINATE                   5217
#define IDS_BADPASSWORD                 5218
#define IDS_RECENT                      5219
#define IDS_RECENTSAFES                 5220
#define IDS_FILEMENU                    5221
#define IDS_EDITMENU                    5222
#define IDS_VIEWMENU                    5223
#define IDS_MANAGEMENU                  5224
#define IDS_OPTIONS                     5225
#define IDS_ENCRYPTIONFAILED            5226
#define IDS_GROUPTITLE                  5227
#define IDS_GROUP                       5228
#define IDS_TITLE                       5229
#define IDS_USERNAME                    5230
#define IDS_PASSWORD                    5231
#define IDS_NOTES                       5232
#define IDS_URL                         5233
#define IDS_CREATED                     5234
#define IDS_PASSWORDMODIFIED            5235
#define IDS_LASTACCESSED                5236
#define IDS_PASSWORDEXPIRYDATE          5237
#define IDS_EXPIRYDATETIME              5238
#define IDS_LASTMODIFIED                5239
#define IDS_COPYTITLE                   5240
#define IDS_PROCESSID                   5241
#define IDS_LOCKED                      5242
#define IDS_FILEINUSE                   5243
#define IDS_FILEOPEN                    5244
#define IDS_SAFENOTEXIST                5245
#define IDS_SAVECHANGES                 5246
#define IDS_NUMITEMS                    5247
#define IDS_NEVER                       5248
#define IDS_HIDDENNOTES                 5249
#define IDS_SHOWPASSWORDTXT1            5250
#define IDS_HIDEPASSWORDTXT1            5251
#define IDS_SHOWPASSWORDTXT2            5252
#define IDS_HIDEPASSWORDTXT2            5253
#define IDS_MUSTHAVETITLE               5254
#define IDS_MUSTHAVEPASSWORD            5255
#define IDS_DOTINVALID                  5256
#define IDS_PASSWORDSNOTMATCH           5257
#define IDS_ENTRYEXISTS                 5258
#define IDS_LESS                        5259
#define IDS_MORE                        5260
#define IDS_ENTRIESDONOTMATCH           5261
#define IDS_ENTERKEYANDVERIFY           5262
#define IDS_PASSWORDOVERRIDE            5263
#define IDS_RANDOMPASSWORD              5264
#define IDS_LOCKSAFE                    5265
#define IDS_UNLOCKSAFE                  5266
#define IDS_NOSAFE                      5267
#define IDS_COPYURL                     5268
#define IDS_COPYAUTOTYPE                5269
#define IDS_DATABASEREADONLY            5270
#define IDS_UNKNOWN                     5271
#define IDS_VIEWENTRY                   5272
#define IDS_ON                          5273
#define IDS_OFF                         5274
#define IDS_NEEDDELIMITER               5275
#define IDS_INVALIDDELIMITER            5276
#define IDS_EQUALS                      5277
#define IDS_DOESNOTEQUAL                5278
#define IDS_BEGINSWITH                  5279
#define IDS_DOESNOTBEGINSWITH           5280
#define IDS_ENDSWITH                    5281
#define IDS_DOESNOTENDWITH              5282
#define IDS_CONTAINS                    5283
#define IDS_DOESNOTCONTAIN              5284
#define IDS_NOFIELDSFOREXPORT           5285
#define IDS_NOOBJECT                    5286
#define IDS_NOFUNCTION                  5287
#define IDS_PASSWORDLISTEMPTY           5288
#define IDS_ENTERSEARCHSTRING           5289
#define IDS_NOMATCHFOUND                5290
#define IDS_FOUNDAMATCH                 5291
#define IDS_FOUNDMATCHES                5292
#define IDS_CONTINUESEARCH              5293
#define IDS_SEARCHNOTFOUND              5294
#define IDS_FINDNEXT                    5295
#define IDS_IMPORTED                    5296
#define IDS_NOCURRENTSAFE               5297
#define IDS_CANNOTBEBLANK               5298
#define IDS_INCORRECTKEY                5299
#define IDS_WEAKPASSPHRASE              5300
#define	IDS_USEITANYWAY                 5301
#define	IDS_TRYANOTHER                  5302
#define	IDS_WRONGOLDPHRASE              5303
#define	IDS_CANTVERIFY                  5304
#define	IDS_NEWOLDDONOTMATCH            5305
#define	IDS_CONFIRMDELETEREG            5306
#define IDS_NOHOTKEY                    5307
#define	IDS_INVALIDTIMEOUT              5308
#define	IDS_HEXMUTUALLYEXCL             5309
#define	IDS_HEXMUSTBEEVEN               5310
#define	IDS_MUSTHAVEONEOPTION           5311
#define	IDS_DEFAULTPWLENGTH             5312
#define	IDS_DEFAULTNUMPWH               5313
#define	IDS_SETDATETIME                 5314
#define IDS_TRAYAUTOTYPE                5315
#define	IDS_TRAYBROWSE                  5316
#define	IDS_TRAYCOPYNOTES               5317
#define	IDS_TRAYCOPYPASSWORD            5318
#define	IDS_TRAYCOPYUSERNAME            5319
#define	IDS_TRAYVIEWEDIT                5320
#define	IDS_TRAYDELETETRAYENTRY         5321
#define	IDS_CANTPROCESSENTRY            5322
#define	IDS_SETUSERNAME                 5326
#define	IDS_NEWGROUP                    5327
#define	IDS_COPYNUMBER                  5328
#define	IDS_COULDNOTSAVE                5329
#define	IDS_SAVEERROR                   5330
#define IDS_CANTBROWSE                  5331
#define	IDS_CANTOPENSAFE                5332
#define	IDS_FILECORRUPT                 5333
#define IDS_FILEREADERROR               5334
#define IDS_SAVEDATABASE                5335
#define IDS_UNTITLED                    5336
#define IDS_CHOOSEDATABASE              5337
#define IDS_ALREADYOPEN                 5338
#define IDS_OPENDATABASE                5339
#define IDS_CANTOPEN                    5340
#define IDS_FILEOPENERROR               5341
#define IDS_CANTOPENREADING             5342
#define IDS_UNKNOWNERROR                5343
#define IDS_NEWFORMAT                   5344
#define IDS_NEWFORMAT2                  5345
#define IDS_VERSIONWARNING              5346
#define IDS_CANTOPENWRITING             5347
#define IDS_FILEWRITEERROR              5348
#define IDS_NEWNAME1                    5349
#define IDS_NEWNAME2                    5350
#define IDS_FILEISLOCKED                5351
#define IDS_FILELOCKERROR               5352
#define IDS_NAMEEXPORTFILE              5353
#define IDS_NAMETEXTFILE                5354
#define IDS_NAMEXMLFILE                 5355
#define IDS_BADPASSKEY                  5356
#define IDS_PICKTEXTFILE                5357
#define IDS_INVALIDFORMAT               5358
#define IDS_STATUS                      5359
#define IDS_RECORDSREAD                 5360
#define IDS_RECORDSNOTREAD              5361
#define IDS_PICKKEEPASSFILE             5362
#define IDS_MISSINGXSD                  5363
#define IDS_CANTVALIDATEXML             5364
#define IDS_PICKXMLFILE                 5365
#define IDS_FAILEDXMLVALIDATE           5366
#define IDS_XMLERRORS                   5367
#define IDS_XMLIMPORTWITHERRORS         5368
#define IDS_XMLIMPORTOK                 5369
#define IDS_PICKMERGEFILE               5370
#define IDS_MERGECONFLICTS              5371
#define IDS_MERGECONFLICTS2             5372
#define IDS_MERGECOMPLETED              5373
#define IDS_MERGECOMPLETED2             5374
#define IDS_NOCOMPAREFILE               5375
#define IDS_PICKCOMPAREFILE             5376
#define IDS_COMPARESAME                 5377
#define IDS_COMPARESTATISTICS           5378
#define IDS_IDENTICALDATABASES          5379
#define IDS_COMPARECOMPLETE             5380
#define IDS_COMPAREONLY1                5381
#define IDS_COMPAREONLY2                5382
#define IDS_COMPAREBOTHDIFF             5383
#define IDS_COMPARECOPYRESULT           5384
#define IDS_COMPARESTATS                5385
#define IDS_COMPAREENTRIES1             5386
#define IDS_COMPAREENTRIES2             5387
#define IDS_COMPAREBOTHDIFF2            5388
#define IDS_COMPARESTATS2               5389
#define IDS_COMPPASSWORD                5390
#define IDS_COMPNOTES                   5391
#define IDS_COMPURL                     5392
#define IDS_COMPAUTOTYPE                5393
#define IDS_COMPCTIME                   5394
#define IDS_COMPPMTIME                  5395
#define IDS_COMPATIME                   5396
#define IDS_COMPLTIME                   5397
#define IDS_COMPRMTIME                  5398
#define IDS_COMPPWHISTORY               5399
#define IDS_SAVEFIRST                   5400
#define IDS_PICKBACKUP                  5401
#define IDS_PICKRESTORE                 5402
#define IDS_UNTITLEDRESTORE             5403
#define IDS_VALIDATEOK                  5404
#define IDS_FAILEDSAVEPREF              5405
#define IDS_FAILEDSAVEPREFRO            5406
#define IDS_ENTRIESCHANGEDSTOP          5407
#define IDS_ENTRIESCHANGEDSAVE          5408
#define IDS_ENTRIESRESETMAX             5409
#define IDS_SELECTBROWSER               5410
#define IDS_NOIBACKUP                   5411
#define IDS_NONE                        5412
#define IDS_INCREMENTNUM                5413
#define IDS_OPTBACKUPPREF               5414
#define IDS_OPTBACKUPSUBDIR             5415
#define IDS_OPTBACKUPLOCATION           5416
#define IDS_OPTBACKUPNOLOC              5417
#define IDS_OPTBACKUPMAXNUM             5418
#define IDS_OPTBACKUPTITLE              5419
#define IDS_DEFDBNAME                   5420

==> pwsafe-3.06-src.zip: pwsafe-3.06-src/resource3.h <==
//{{NO_DEPENDENCIES}}

// Strings
#define DEFAULT_SUFFIX _T("psafe3")
#define SUFFIX_FILTERS _T("Password Safe Databases (*.psafe3; *.dat)|*.psafe3; *.dat|")
#define SUFFIX3_FILTERS _T("Password Safe Databases (*.psafe3)|*.psafe3|")

//  Usage
#define IDS_USAGE                       5000

// Window state
#define IDS_ALWAYSONTOP                 5010

// Status bar
#define IDS_STATCOMPANY                 5020
#define IDS_STATAUTOTYPE                5021
#define IDS_STATBROWSE                  5022
#define IDS_STATCOPYNOTES               5023
#define IDS_STATCOPYPASSWORD            5024
#define IDS_STATCOPYUSERNAME            5025
#define IDS_STATVIEWEDIT                5026
#define IDS_MODIFIED                    5027
#define IDS_READ_ONLY                   5028
#define IDS_STAT_NUM_IN_DB              5029
#define IDS_CONFIG_BLANK                5030

// Tooltips
#define IDS_RESETPWHISTORYOFF           5100
#define IDS_RESETPWHISTORYON            5101
#define IDS_SETMAXPWHISTORY             5102
#define IDS_REGDEL_CB                   5103
#define IDS_BACKUPBEFORESAVE            5104
#define IDS_USERBACKUPOTHERLOCATION     5106
#define IDS_MAINTAINDATETIMESTAMPS      5107
#define IDS_OTHERBROWSERLOCATION        5108

// Program strings
#define IDS_DCAAUTOTYPE                 5200
#define IDS_DCABROWSE                   5201
#define IDS_DCACOPYNOTES                5202
#define IDS_DCACOPYPASSWORD             5203
#define IDS_DCACOPYUSERNAME             5204
#define IDS_DCAVIEWEDIT                 5205
#define IDS_LITTLEENDIAN                5206
#define IDS_BIGENDIAN                   5207
#define IDS_ENDIANERROR                 5208
#define IDS_FILEERROR1                  5209
#define IDS_FILEERROR2                  5210
#define IDS_ERRORMESSAGE                5211
#define IDS_FILEREADONLY                5212
#define IDS_FILEEXISTS                  5213
#define IDS_INVALIDFLAG                 5214
#define IDS_NOMOREHANDLES               5215
#define IDS_FILEPATHNOTFOUND            5216
#define IDS_TERMINATE                   5217
#define IDS_BADPASSWORD                 5218
#define IDS_RECENT                      5219
#define IDS_RECENTSAFES                 5220
#define IDS_FILEMENU                    5221
#define IDS_EDITMENU                    5222
#define IDS_VIEWMENU                    5223
#define IDS_MANAGEMENU                  5224
#define IDS_OPTIONS                     5225
#define IDS_ENCRYPTIONFAILED            5226
#define IDS_GROUPTITLE                  5227
#define IDS_GROUP                       5228
#define IDS_TITLE                       5229
#define IDS_USERNAME                    5230
#define IDS_PASSWORD                    5231
#define IDS_NOTES                       5232
#define IDS_URL                         5233
#define IDS_CREATED                     5234
#define IDS_PASSWORDMODIFIED            5235
#define IDS_LASTACCESSED                5236
#define IDS_PASSWORDEXPIRYDATE          5237
#define IDS_EXPIRYDATETIME              5238
#define IDS_LASTMODIFIED                5239
#define IDS_COPYTITLE                   5240
#define IDS_PROCESSID                   5241
#define IDS_LOCKED                      5242
#define IDS_FILEINUSE                   5243
#define IDS_FILEOPEN                    5244
#define IDS_SAFENOTEXIST                5245
#define IDS_SAVECHANGES                 5246
#define IDS_NUMITEMS                    5247
#define IDS_NEVER                       5248
#define IDS_HIDDENNOTES                 5249
#define IDS_SHOWPASSWORDTXT1            5250
#define IDS_HIDEPASSWORDTXT1            5251
#define IDS_SHOWPASSWORDTXT2            5252
#define IDS_HIDEPASSWORDTXT2            5253
#define IDS_MUSTHAVETITLE               5254
#define IDS_MUSTHAVEPASSWORD            5255
#define IDS_DOTINVALID                  5256
#define IDS_PASSWORDSNOTMATCH           5257
#define IDS_ENTRYEXISTS                 5258
#define IDS_LESS                        5259
#define IDS_MORE                        5260
#define IDS_ENTRIESDONOTMATCH           5261
#define IDS_ENTERKEYANDVERIFY           5262
#define IDS_PASSWORDOVERRIDE            5263
#define IDS_RANDOMPASSWORD              5264
#define IDS_LOCKSAFE                    5265
#define IDS_UNLOCKSAFE                  5266
#define IDS_NOSAFE                      5267
#define IDS_COPYURL                     5268
#define IDS_COPYAUTOTYPE                5269
#define IDS_DATABASEREADONLY            5270
#define IDS_UNKNOWN                     5271
#define IDS_VIEWENTRY                   5272
#define IDS_ON                          5273
#define IDS_OFF                         5274
#define IDS_NEEDDELIMITER               5275
#define IDS_INVALIDDELIMITER            5276
#define IDS_EQUALS                      5277
#define IDS_DOESNOTEQUAL                5278
#define IDS_BEGINSWITH                  5279
#define IDS_DOESNOTBEGINSWITH           5280
#define IDS_ENDSWITH                    5281
#define IDS_DOESNOTENDWITH              5282
#define IDS_CONTAINS                    5283
#define IDS_DOESNOTCONTAIN              5284
#define IDS_NOFIELDSFOREXPORT           5285
#define IDS_NOOBJECT                    5286
#define IDS_NOFUNCTION                  5287
#define IDS_PASSWORDLISTEMPTY           5288
#define IDS_ENTERSEARCHSTRING           5289
#define IDS_NOMATCHFOUND                5290
#define IDS_FOUNDAMATCH                 5291
#define IDS_FOUNDMATCHES                5292
#define IDS_CONTINUESEARCH              5293
#define IDS_SEARCHNOTFOUND              5294
#define IDS_FINDNEXT                    5295
#define IDS_IMPORTED                    5296
#define IDS_NOCURRENTSAFE               5297
#define IDS_CANNOTBEBLANK               5298
#define IDS_INCORRECTKEY                5299
#define IDS_WEAKPASSPHRASE              5300
#define	IDS_USEITANYWAY                 5301
#define	IDS_TRYANOTHER                  5302
#define	IDS_WRONGOLDPHRASE              5303
#define	IDS_CANTVERIFY                  5304
#define	IDS_NEWOLDDONOTMATCH            5305
#define	IDS_CONFIRMDELETEREG            5306
#define IDS_NOHOTKEY                    5307
#define	IDS_INVALIDTIMEOUT              5308
#define	IDS_HEXMUTUALLYEXCL             5309
#define	IDS_HEXMUSTBEEVEN               5310
#define	IDS_MUSTHAVEONEOPTION           5311
#define	IDS_DEFAULTPWLENGTH             5312
#define	IDS_DEFAULTNUMPWH               5313
#define	IDS_SETDATETIME                 5314
#define IDS_TRAYAUTOTYPE                5315
#define	IDS_TRAYBROWSE                  5316
#define	IDS_TRAYCOPYNOTES               5317
#define	IDS_TRAYCOPYPASSWORD            5318
#define	IDS_TRAYCOPYUSERNAME            5319
#define	IDS_TRAYVIEWEDIT                5320
#define	IDS_TRAYDELETETRAYENTRY         5321
#define	IDS_CANTPROCESSENTRY            5322
#define	IDS_SETUSERNAME                 5326
#define	IDS_NEWGROUP                    5327
#define	IDS_COPYNUMBER                  5328
#define	IDS_COULDNOTSAVE                5329
#define	IDS_SAVEERROR                   5330
#define IDS_CANTBROWSE                  5331
#define	IDS_CANTOPENSAFE                5332
#define	IDS_FILECORRUPT                 5333
#define IDS_FILEREADERROR               5334
#define IDS_SAVEDATABASE                5335
#define IDS_UNTITLED                    5336
#define IDS_CHOOSEDATABASE              5337
#define IDS_ALREADYOPEN                 5338
#define IDS_OPENDATABASE                5339
#define IDS_CANTOPEN                    5340
#define IDS_FILEOPENERROR               5341
#define IDS_CANTOPENREADING             5342
#define IDS_UNKNOWNERROR                5343
#define IDS_NEWFORMAT                   5344
#define IDS_NEWFORMAT2                  5345
#define IDS_VERSIONWARNING              5346
#define IDS_CANTOPENWRITING             5347
#define IDS_FILEWRITEERROR              5348
#define IDS_NEWNAME1                    5349
#define IDS_NEWNAME2                    5350
#define IDS_FILEISLOCKED                5351
#define IDS_FILELOCKERROR               5352
#define IDS_NAMEEXPORTFILE              5353
#define IDS_NAMETEXTFILE                5354
#define IDS_NAMEXMLFILE                 5355
#define IDS_BADPASSKEY                  5356
#define IDS_PICKTEXTFILE                5357
#define IDS_INVALIDFORMAT               5358
#define IDS_STATUS                      5359
#define IDS_RECORDSIMPORTED             5360
#define IDS_RECORDSNOTREAD              5361
#define IDS_PICKKEEPASSFILE             5362
#define IDS_MISSINGXSD                  5363
#define IDS_CANTVALIDATEXML             5364
#define IDS_PICKXMLFILE                 5365
#define IDS_FAILEDXMLVALIDATE           5366
#define IDS_XMLERRORS                   5367
#define IDS_XMLIMPORTWITHERRORS         5368
#define IDS_XMLIMPORTOK                 5369
#define IDS_PICKMERGEFILE               5370
#define IDS_MERGECONFLICTS              5371
#define IDS_MERGECONFLICTS2             5372
#define IDS_MERGECOMPLETED              5373
#define IDS_MERGECOMPLETED2             5374
#define IDS_NOCOMPAREFILE               5375
#define IDS_PICKCOMPAREFILE             5376
#define IDS_COMPARESAME                 5377
#define IDS_COMPARESTATISTICS           5378
#define IDS_IDENTICALDATABASES          5379
#define IDS_COMPARECOMPLETE             5380
#define IDS_COMPAREONLY1                5381
#define IDS_COMPAREONLY2                5382
#define IDS_COMPAREBOTHDIFF             5383
#define IDS_COMPARECOPYRESULT           5384
#define IDS_COMPARESTATS                5385
#define IDS_COMPAREENTRIES1             5386
#define IDS_COMPAREENTRIES2             5387
#define IDS_COMPAREBOTHDIFF2            5388
#define IDS_COMPARESTATS2               5389
#define IDS_COMPPASSWORD                5390
#define IDS_COMPNOTES                   5391
#define IDS_COMPURL                     5392
#define IDS_COMPAUTOTYPE                5393
#define IDS_COMPCTIME                   5394
#define IDS_COMPPMTIME                  5395
#define IDS_COMPATIME                   5396
#define IDS_COMPLTIME                   5397
#define IDS_COMPRMTIME                  5398
#define IDS_COMPPWHISTORY               5399
#define IDS_SAVEFIRST                   5400
#define IDS_PICKBACKUP                  5401
#define IDS_PICKRESTORE                 5402
#define IDS_UNTITLEDRESTORE             5403
#define IDS_VALIDATEOK                  5404
#define IDS_FAILEDSAVEPREF              5405
#define IDS_FAILEDSAVEPREFRO            5406
#define IDS_ENTRIESCHANGEDSTOP          5407
#define IDS_ENTRIESCHANGEDSAVE          5408
#define IDS_ENTRIESRESETMAX             5409
#define IDS_SELECTBROWSER               5410
#define IDS_NOIBACKUP                   5411
#define IDS_NONE                        5412
#define IDS_INCREMENTNUM                5413
#define IDS_OPTBACKUPPREF               5414
#define IDS_OPTBACKUPSUBDIR             5415
#define IDS_OPTBACKUPLOCATION           5416
#define IDS_OPTBACKUPNOLOC              5417
#define IDS_OPTBACKUPMAXNUM             5418
#define IDS_OPTBACKUPTITLE              5419
#define IDS_DEFDBNAME                   5420
#define IDS_CREATENAME                  5421
#define IDS_DEMO                        5422
#define IDS_LIMIT_TITLE                 5423
#define IDS_LIMIT_MSG                   5424
#define IDS_LIMIT_MSG2                  5425
#define IDS_MENUEXPCOLGROUP             5426
#define IDS_MENUEDITENTRY               5427
#define IDS_MENUVIEWENTRY               5428
#define IDS_MENUDELETEENTRY             5429
#define IDS_MENUDELETEGROUP             5430
#define IDS_MENURENAMEENTRY             5431
#define IDS_MENURENAMEGROUP             5432
#define IDS_MAXNUMDAYSEXCEEDED          5433
#define IDS_HELPMENU                    5434
#define IDS_U3PURCHASE                  5435
